.TH sane-mustek 5 "25 July 1997"
.IX sane-mustek
.SH NAME
sane-mustek - SANE backend for Mustek flatbed scanners
.SH DESCRIPTION
The
.B sane-mustek
library implements a SANE (Scanner Access Now Easy) backend that
provides access to Mustek flatbed scanners.  At present, the following
scanners are known positively to work with this backend:
.PP
.RS
Model:      Product id:    Firmware revision: Type:
.br
----------- ----------- ------------------ -----
.br
MFC-600S    MFC-06000CZ v1.01 (and higher) 1-pass
.br
MFC-600CD   MFC-06000CZ v2.03 (and higher) 1-pass
.br
MFS-6000CX  MSF-06000CX v2.71 (and higher) 3-pass
.br
MSF-6000SP  MSF-06000SP v3.12 (and higher) 1-pass
.br
MFS-8000SP  MFS-08000SP v2.05 [b&w has line drops] 1-pass
.br
MFS-1200SP  MSF-12000SP v1.00 (and higher) 1-pass
.br
MFS-1200SP  MFS-12000SP v1.02 [color fails?] 1-pass
.br
MFS-12000CX MFS-12000CX v2.71 (and higher) 3-pass
.RE
.PP
Note that this list includes both single- and three-pass scanners, so
in all likelihood, pretty much any Mustek flatbed scanner should work
with this backend.  If you own a Mustek scanner other than the ones
listed above, please let us know if your model works with this
backend.  To do this, send a mail with the relevant information for
your scanner to
.IR sane-devel@listserv.azstarnet.com .

.SH "DEVICE NAMES"
This backend expects device names of the form:
.PP
.RS
.IR special
.RE
.PP
Where
.I special
is the UNIX path-name for the special device that corresponds to the
scanner.  The special device name must be a generic SCSI device or a
symlink to such a device.  Under Linux, such a device name could be
.IR /dev/sga
or
.IR /dev/sge ,
for example.
.SH CONFIGURATION
The configuration file for this backend resides in
.IR @CONFIGDIR@/mustek.conf .
Its contents is a list of options and device names that correspond to
Mustek scanners.  Empty lines and lines starting with a hash mark (#)
are ignored.
.PP
The only option supported at this point is the
.B strip-height
option.  It limits the maximum height of the strip scanned with a
single SCSI read command.  The height is specified in inches and may
contain a fractional part (e.g., 1.5).  Setting the strip-height to a
small value (one inch, for example) reduces the likelihood of
encountering problems with SCSI driver timeouts and/or timeouts with
other devices on the same SCSI bus.  Unfortunately, it also increases
scan times.  Thus, if the scanner is the only device on the SCSI bus
it is connected to and if it is known that the SCSI driver does not
suffer from premature timeouts, it is recommended to increase the
strip-height or remove the option completely, which corresponds to an
infinite strip height.  See sane-scsi(5) on how to avoid problems with
SCSI timeouts.
.PP
A sample configuration file is shown below:
.PP
.RS
# limit strip height to one and a half inch:
.br
option strip-height 1.5
.br
/dev/scanner
.br
/dev/sge
.RE

.SH SCSI ADAPTER TIPS
Mustek SCSI scanners are typically delivered with an ISA SCSI adapter.
Unfortunately, that adapter is not worth much since it is not
interrupt driven.  It is (sometimes) possible to get the supplied card
to work, but without interrupt line, scanning will put so much load on
the system, that it becomes almost unusable for other tasks.
.PP
If you already have a working SCSI controller in your system, you
should consider that Mustek scanners do not support the SCSI-2
disconnect/reconnect protocol and hence tie up the SCSI bus while a
scan is in progress.  This means that no other SCSI device on the same
bus can be accessed while a scan is in progress.
.PP
Because the Mustek-supplied adapter is not worth much and because
Mustek scanners do not support the SCSI-2 disconnect/reconnect
protocol, it is recommended to install a separate (cheap) SCSI
controller for Mustek scanners.  For example, ncr810 based cards are
known to work fine and cost as little as fifty US dollars.
.PP
For Mustek scanners, it is typically necessary to configure the
low-level SCSI driver to disable synchronous transfers, tagged command
queuing, and target disconnects.  See sane-scsi(5) for driver and
platform-specific information.
.SH FILES
.TP
.I @CONFIGDIR@/mustek.conf
The backend configuration file.
.TP
.I @LIBDIR@/libsane-mustek.a
The static library implementing this backend.
.TP
.I @LIBDIR@/libsane-mustek.so
The shared library implementing this backend (present on systems that
support dynamic loading).
.SH ENVIRONMENT
.TP
.B SANE_DEBUG_MUSTEK
If the library was compiled with debug support enabled, this
environment variable controls the debug level for this backend.  E.g.,
a value of 128 requests all debug output to be printed.  Smaller
levels reduce verbosity.
.SH "SEE ALSO"
sane-scsi(5)
.SH AUTHOR
David Mosberger
.SH BUGS
Transparency adapter and automatic document feeder support is severly
lacking (due to absence of equipment to test this with).

There seems to be a performance bug that makes scanning on (some)
three-pass scanner slower than necessary.
